DateUtilities class
A date utility interface to get every information of dates, months, weeks and year taking leap year into consideration.
Constructors
Properties
Methods
-
day(
int length) → String? -
dayGivenDayOfYear(
int dof, int year) → int -
daysInMonth(
int monthNum, int year) → int? - "Given a month number and a year, return the number of days in that month."
-
daysInYear(
int year) → int - It returns the number of days past in the year.
-
daysLeftInYear(
int monthNum, int dayNum, int year) → int - It returns the number of days left in the year.
-
daysPastInYear(
int monthNum, int dayNum, int year) → int - It returns the number of days past in the year.
-
getMonthGivenDayOfYear(
int days, int year) → int -
getNumberOfDaysGivenMonth(
int month, int year) → int -
getWeek(
int monthNum, int dayNum, int year) → int - It returns the week number of the year.
-
leapYear(
int year) → bool - Given a year, return true if it's a leap year, false otherwise.
-
month(
int monthNum) → String - It returns the name of the month for the given month number
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printMonthCalendar(
int monthNum, int year) → void - Prints the calendar for the given month and year.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited