month method
It returns the name of the month for the given month number
Args: monthNum (int): The number of the month to get the name of.
Implementation
String month(final int monthNum) {
final month = <String>[
'January',
'February',
'March',
'April',
'May',
'June',
'July',
'August',
'September',
'October',
'November',
'December'
];
return month[monthNum - 1];
}